Add some new HIP_TRACE_API options.

[ROCm/hip commit: e3161bb40e]
This commit is contained in:
Ben Sander
2017-08-16 03:50:04 +00:00
rodzic c26e1d8c3d
commit 542bd863a2
4 zmienionych plików z 13 dodań i 10 usunięć
+3 -2
Wyświetl plik
@@ -84,7 +84,7 @@ hipError_t hipStreamCreate(hipStream_t *stream)
hipError_t hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int flags)
{
HIP_INIT_API(stream, event, flags);
HIP_INIT_SPECIAL_API(TRACE_SYNC, stream, event, flags);
hipError_t e = hipSuccess;
@@ -114,7 +114,7 @@ hipError_t hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int
//---
hipError_t hipStreamQuery(hipStream_t stream)
{
HIP_INIT_API(stream);
HIP_INIT_SPECIAL_API(TRACE_QUERY, stream);
// Use default stream if 0 specified:
if (stream == hipStreamNull) {
@@ -140,6 +140,7 @@ hipError_t hipStreamQuery(hipStream_t stream)
hipError_t hipStreamSynchronize(hipStream_t stream)
{
HIP_INIT_API(stream);
HIP_INIT_SPECIAL_API(TRACE_SYNC, stream);
hipError_t e = hipSuccess;